from setuptools import setup, find_packages

setup(
    name="kygame",
    version="0.1.2",
    author="Богдан",
    packages=find_packages(),
    install_requires=[
        "kivy",
        "pygame",
    ],
)

